/*
	File:		TestFunctions.c

	Contains:	Test functions for Sequence grabber and vdig tests.

	Written by:	DTS

	Copyright:	 1995 by Apple Computer, Inc., all rights reserved.

	Change History (most recent first):

	    <1>	 	4/25/95	khs		first file
	   
*/


// INCLUDES
#include "TestFunctions.h"

#include "DTSQTUtilities.h"
#include "MacFramework.h"


// FUNCTIONS
// ______________________________________________________________________
OSErr ShowVDIGInfo(void)
{
	OSErr anErr = noErr;
	VideoDigitizerComponent vd = NULL;
	DigitizerInfo					  digInfo;
	
	printf("\nINFORMATION: Video Digitizer (default component):\n");
	
	vd = SGGetVideoDigitizerComponent( GetDefaultVideoChannel() ); DebugAssert(vd != NULL);
	if(vd == NULL)
	{
		printf("ERROR: Problems getting the vdig component instance from video channel.\n");
		goto Closure;
	}

	// Test for live incoming video signal.
	if(QTUDoesVDIGReceiveVideo(vd))
		printf("Vdig is currently receiving a video signal.\n");
	else
		printf("Vdig is currently NOT receiving a video signal.\n");
	
	
	anErr = VDGetDigitizerInfo(vd, &digInfo); DebugAssert(anErr == noErr);
	if(anErr != noErr)
	{
		printf("ERROR: Problems getting Digitizer Information.\n");
		goto Closure;
	}

	// Vdig type.
	printf("\nVdig Type = ");
	switch (digInfo.vdigType)
	{
		case vdTypeBasic:
			printf("vdTypeBasic (basic video digitizer, does not support any clipping.\n");
			break;

		case vdTypeAlpha:
			printf("vdTypeAlpha (supports clipping by means of an alpha channel).\n");
			break;

		case vdTypeMask:
			printf("vdTypeMask (supports clipping by means of a mask plane).\n");
			break;

		case vdTypeKey:
			printf("vdTypeKey (supports clipping by means of key colors).\n");
			break;
	}
	
	// Input Capabilities (default ones)
	printf("\nThe vdig handles the following inputs:\n");
	if(digInfo.inputCapabilityFlags & digiInDoesNTSC)
		printf("\tNTSC\n");		
	if(digInfo.inputCapabilityFlags & digiInDoesPAL)
		printf("\tPAL\n");
	if(digInfo.inputCapabilityFlags & digiInDoesSECAM)
		printf("\tSECAM\n");
	if(digInfo.inputCapabilityFlags & digiInDoesGenLock)
		printf("\tGenlock\n");
	if(digInfo.inputCapabilityFlags & digiInDoesComposite)
		printf("\tComposite Video\n");
	if(digInfo.inputCapabilityFlags & digiInDoesSVideo)
		printf("\tS-Video\n");
	if(digInfo.inputCapabilityFlags & digiInDoesComponent)
		printf("\tRGB input video\n");
	if(digInfo.inputCapabilityFlags & digiInDoesColor)
		printf("\tColor input\n");
	if(digInfo.inputCapabilityFlags & digiInDoesBW)
		printf("\tGrayScale input\n");
	
	if(digInfo.inputCurrentFlags & digiInSignalLock)
		printf("\tCurrently the vdig is locked onto the input signal.\n");
		
		
	// Output Capabilities.
		printf("\nThe vdig handles the following output cases:\n");
		printf("Pixel Maps of size (bit): ");
	if(digInfo.outputCapabilityFlags & digiOutDoes1)
		printf("1 ");		
	if(digInfo.outputCapabilityFlags & digiOutDoes2)
		printf("2 ");		
	if(digInfo.outputCapabilityFlags & digiOutDoes4)
		printf("4 ");		
	if(digInfo.outputCapabilityFlags & digiOutDoes8)
		printf("8 ");		
	if(digInfo.outputCapabilityFlags & digiOutDoes16)
		printf("16 ");		
	if(digInfo.outputCapabilityFlags & digiOutDoes32)
		printf("32 ");		

	printf("\n");
	
	if(digInfo.outputCapabilityFlags & digiOutDoesDither)
		printf("Handles dithering out.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesStretch)
		printf("Handles stretching of images.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesShrink)
		printf("Handles shrinking of images.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesDouble)
		printf("Handles doubling (stretching to quadruple size) of images.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesQuad)
		printf("Handles stretching image to 16 times original size.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesQuarter)
		printf("Handles shrinking image to 1/4 times original size.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesSixteenth)
		printf("Handles shrinking image to 1/16 times original size.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesRotate)
		printf("Handles rotation of image displayed.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesHorizFlip)
		printf("Handles horizontal flip of image displayed.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesVertFlip)
		printf("Handles vertical flip of image displayed.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesSkew)
		printf("Handles skew of image displayed.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesBlend)
		printf("Handles blend of image with matte.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesWarp)
		printf("Handles warp of image (distortion along an axis).\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesHW_DMA)
		printf("Handles DMA writes to screen or offscreen memory.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesHWPlayThru)
		printf("Handles Playthrough mode (no need for idle time).\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesILUT)
		printf("Handles inverse lookup tables for indexed color modes.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesKeyColor)
		printf("Handles clipping by using key colors.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesAsyncGrabs)
		printf("Can operate asynchronously.\n");
	
	if(digInfo.outputCapabilityFlags & digiOutDoesUnreadableScreenBits)
		printf("Vdig might place pixels on the screeen that can't be used when compressing images.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesCompress)
		printf("Vdig supports compressed source devices.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesCompressOnly)
		printf("Vdig only provides compressed image data.\n");
	if(digInfo.outputCapabilityFlags & digiOutDoesPlayThruDuringCompress)
		printf("Vdig can't draw images on the screen while it's delivering compressed images.\n");
	

	// Size.
	printf("\n\nSmallest resizable height = \t%d.\n", digInfo.minDestHeight);
	printf("Smallest resizable width = \t%d.\n", digInfo.minDestWidth);
	printf("Largest resizable height = \t%d.\n", digInfo.maxDestHeight);
	printf("Largest resizable width = \t%d.\n", digInfo.maxDestWidth);
	
	// Blending.
	printf("\nBlend level = \t%d (2 if 1-bit mask).\n", digInfo.blendLevels);

Closure:
	return anErr;
}


// ______________________________________________________________________
void SetMyVideoChannelSettings(void)
{
	OSErr anErr = noErr;
	
	anErr = SGSettingsDialog( GetDefaultSGInstance(), GetDefaultVideoChannel(), 0, NULL,
											DoTheRightThing, NULL, 0); DebugAssert(anErr == noErr);
}


// ______________________________________________________________________
void SetMyAudioChannelSettings(void)
{
	OSErr anErr = noErr;
	
	anErr = SGSettingsDialog( GetDefaultSGInstance(), GetDefaultAudioChannel(), 0, NULL,
											DoTheRightThing, NULL, 0); DebugAssert(anErr == noErr);
}


